@@ -33,10 +33,16 @@ sub get_points {
     push(@points, Geometry::Primitive::Point->new(
         x => $self->origin->x + $self->width, y => $self->origin->y + $self->height
     ));
-
     return \@points
 }
 
+sub scale {
+    my ($self, $amount) = @_;
+
+    $self->width($self->width * $amount);
+    $self->height($self->height * $amount);
+}
+
 sub point_end {
     my ($self) = @_; return $self->origin;
 }
@@ -102,6 +108,10 @@ Get the end point.  Returns the origin. Provided for Shape role.
 
 Get the start point.  Returns the origin.  Provided for Shape role.
 
+=item I<scale ($amount)>
+
+Scales the hieght and width of this rectangle by the amount specified.
+
 =item I<width>
 
 Add a point to this Rectangle.
